package jwebcache;

import org.apache.log4j.Logger;

import java.util.*;
import java.io.*;

import net.i2p.client.streaming.I2PSocket;


public class SocketTimeout extends TimerTask {

    // Our logger instance.
    private static Logger logger = Logger.getLogger(SocketTimeout.class);
    
    // References to important objects.
    private I2PSocket socket; // Socket which we target.
    private long requestId; // For more informative logging only.


    public SocketTimeout(I2PSocket socket, long requestId) {

        // Grab arguments to local variables.
        this.socket = socket;
        this.requestId = requestId;
    }


    public boolean cancel() {

        // Call parent to get cancelled properly.
        return super.cancel();
    }


    public void run() {

        if (socket != null) {
            try {
                if (!socket.isClosed()) {
                    logger.warn("Timeout reached, closing socket for " + requestId + "!");
                    socket.close();
                } else logger.warn("Timeout reached, but socket for " + requestId + " already closed.");
                
            } catch (IOException e) {
                logger.error("Timeout failed closing socket for " + requestId + "!",e);
            } finally {
                socket = null;
            }
        } else logger.warn("Timeout reached, but socket for " + requestId + " already null.");
    }
    
}

